# straightemail

This package aims to ease sending emails.

In send_email module, there is a send_email function which takes in the following arguments.

| Parameter | Description |
| --------- | ----------- | 
| sender_email   | Email of the sender | 
| sender_password | Password of the sender | 
| subject | Subject of the email | 
| content | Body of the email | 
| attachments | List of the paths(in string format) to attachments | 
| to_email_list | To email addresses | 
| cc_email_list | Cc email addresses | 
| smtp_server | SMTP server | 
| smtp_port | SMTP port | 
